@@ -6,7 +6,7 @@ import traceback
 from datetime import datetime
 import pandas as pd
 from typing import Tuple
-import exceptions
+import fscloudutils.exceptions as exceptions
 
 
 class NavRowData:
@@ -136,5 +136,5 @@ class NavParser:
     def get_points(self) -> dict:  # getter function
         return self._points
 
-    def get_most_accurate_point(self):
-        return max(self._points, key=lambda s: self._points[s].get_satellites_count())
\ No newline at end of file
+    def get_most_accurate_point(self) -> NavRowData:
+        return max(self._points, key=lambda s: self._points[s].get_satellites_count())
